RectTransform

Struct RectTransform 

pub struct RectTransform { /* private fields */ }
Linearly transforms positions from one Rect to another.

RectTransform stores the rectangles, and therefore supports clamping and culling.

Implementations

Source

impl RectTransform

pub fn identity(from_and_to: Rect) -> RectTransform

pub fn from_to(from: Rect, to: Rect) -> RectTransform

pub fn from(&self) -> &Rect

pub fn to(&self) -> &Rect

pub fn scale(&self) -> Vec2

The scale factors.

pub fn inverse(&self) -> RectTransform

pub fn transform_pos(&self, pos: Pos2) -> Pos2

Transforms the given coordinate in the from space to the to space.

pub fn transform_rect(&self, rect: Rect) -> Rect

Transforms the given rectangle in the in-space to a rectangle in the out-space.

pub fn transform_pos_clamped(&self, pos: Pos2) -> Pos2

Transforms the given coordinate in the from space to the to space, clamping if necessary.