macro_rules! epaint_assert {
($($arg:tt)*) => { ... };
}Expand description
An assert that is only active when egui is compiled with the egui_assert feature
or with the debug_egui_assert feature in debug builds.
macro_rules! epaint_assert {
($($arg:tt)*) => { ... };
}An assert that is only active when egui is compiled with the egui_assert feature
or with the debug_egui_assert feature in debug builds.