pub struct ComboBox { /* private fields */ }Expand description
A drop-down selection menu with a descriptive label.
egui::ComboBox::from_label( "Select one!")
.selected_text(format!("{:?}", selected))
.show_ui(ui, |ui| {
ui.selectable_value(&mut selected, Enum::First, "First");
ui.selectable_value(&mut selected, Enum::Second, "Second");
ui.selectable_value(&mut selected, Enum::Third, "Third");
}
);Implementations
Sourceimpl ComboBox
impl ComboBox
Sourcepub fn from_label(label: impl Into<Label>) -> ComboBox
pub fn from_label(label: impl Into<Label>) -> ComboBox
Label shown next to the combo box
Sourcepub fn from_id_source(id_source: impl Hash) -> ComboBox
pub fn from_id_source(id_source: impl Hash) -> ComboBox
Without label.
Sourcepub fn selected_text(self, selected_text: impl ToString) -> ComboBox
pub fn selected_text(self, selected_text: impl ToString) -> ComboBox
What we show as the currently selected value
Sourcepub fn show_ui<R>(
self,
ui: &mut Ui,
menu_contents: impl FnOnce(&mut Ui) -> R,
) -> InnerResponse<Option<R>>
pub fn show_ui<R>( self, ui: &mut Ui, menu_contents: impl FnOnce(&mut Ui) -> R, ) -> InnerResponse<Option<R>>
Show the combo box, with the given ui code for the menu contents.
Returns InnerResponse { inner: None } if the combo box is closed.
Sourcepub fn show_index(
self,
ui: &mut Ui,
selected: &mut usize,
len: usize,
get: impl Fn(usize) -> String,
) -> Response
pub fn show_index( self, ui: &mut Ui, selected: &mut usize, len: usize, get: impl Fn(usize) -> String, ) -> Response
Show a list of items with the given selected index.
let alternatives = ["a", "b", "c", "d"];
let mut selected = 2;
egui::ComboBox::from_label( "Select one!").show_index(
ui,
&mut selected,
alternatives.len(),
|i| alternatives[i].to_owned()
);Auto Trait Implementations
impl Freeze for ComboBox
impl RefUnwindSafe for ComboBox
impl Send for ComboBox
impl Sync for ComboBox
impl Unpin for ComboBox
impl UnsafeUnpin for ComboBox
impl UnwindSafe for ComboBox