pub struct ProgressBar { /* private fields */ }Expand description
A simple progress bar.
Implementations
Sourceimpl ProgressBar
impl ProgressBar
Sourcepub fn new(progress: f32) -> ProgressBar
pub fn new(progress: f32) -> ProgressBar
Progress in the [0, 1] range, where 1 means “completed”.
Sourcepub fn desired_width(self, desired_width: f32) -> ProgressBar
pub fn desired_width(self, desired_width: f32) -> ProgressBar
The desired width of the bar. Will use all horizontal space if not set.
Sourcepub fn text(self, text: impl ToString) -> ProgressBar
pub fn text(self, text: impl ToString) -> ProgressBar
A custom text to display on the progress bar.
Sourcepub fn show_percentage(self) -> ProgressBar
pub fn show_percentage(self) -> ProgressBar
Show the progress in percent on the progress bar.
Sourcepub fn animate(self, animate: bool) -> ProgressBar
pub fn animate(self, animate: bool) -> ProgressBar
Whether to display a loading animation when progress < 1.
Note that this will cause the UI to be redrawn.
Defaults to false.