pub struct Separator { /* private fields */ }Expand description
A visual separator. A horizontal or vertical line (depending on Layout).
Usually you’d use the shorter version Ui::separator.
// These are equivalent:
ui.separator();
ui.add(egui::Separator::default());Implementations
Sourceimpl Separator
impl Separator
pub fn new() -> Separator
👎Deprecated:
Use Separator::default() instead
Sourcepub fn spacing(self, spacing: f32) -> Separator
pub fn spacing(self, spacing: f32) -> Separator
How much space we take up. The line is painted in the middle of this.
Sourcepub fn horizontal(self) -> Separator
pub fn horizontal(self) -> Separator
Explicitly ask for a horizontal line. By default you will get a horizontal line in vertical layouts, and a vertical line in horizontal layouts.